# wxy121517761848


[![pypi](https://img.shields.io/pypi/v/wxy121517761848.svg)](https://pypi.org/project/wxy121517761848/)
[![python](https://img.shields.io/pypi/pyversions/wxy121517761848.svg)](https://pypi.org/project/wxy121517761848/)
[![Build Status](https://github.com/nazq/wxy121517761848/actions/workflows/dev.yml/badge.svg)](https://github.com/nazq/wxy121517761848/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/nazq/wxy121517761848/branch/main/graphs/badge.svg)](https://codecov.io/github/nazq/wxy121517761848)



Some lite description


* Documentation: <https://nazq.github.io/wxy121517761848>
* GitHub: <https://github.com/nazq/wxy121517761848>
* PyPI: <https://pypi.org/project/wxy121517761848/>
* Free software: Apache-2.0


## Features

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [cheeyeelim/cookiecutter-pypackage](https://github.com/cheeyeelim/cookiecutter-pypackage) project template.
